---
title: <span class="badge builder"></span> TableSortByFieldState
---
# <span class="badge builder"></span> TableSortByFieldState

## Constructor

```python
TableSortByFieldState()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.TableSortByFieldState
```

### <span class="badge object-method"></span> desc

Flag used to indicate descending sort order

```python
def desc(desc: bool) -> typing.Self
```

### <span class="badge object-method"></span> display_name

Sets the display name of the field to sort by

```python
def display_name(display_name: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [TableSortByFieldState](./object-TableSortByFieldState.md)
